@@ -31,6 +31,7 @@
 #include "terminal-schemas.h"
 #include "terminal-type-builtins.h"
 #include "terminal-util.h"
+#include "terminal-profile-utils.h"
 
 typedef struct _TerminalColorScheme TerminalColorScheme;
 
@@ -490,6 +491,9 @@ scroll_event_cb (GtkWidget      *widget,
   GtkNotebook *notebook = GTK_NOTEBOOK (widget);
   GtkWidget *child, *event_widget, *action_widget;
 
+  if ((event->state & gtk_accelerator_get_default_mod_mask ()) != 0)
+    return FALSE;
+
   child = gtk_notebook_get_nth_page (notebook, gtk_notebook_get_current_page (notebook));
   if (child == NULL)
     return FALSE;
@@ -706,6 +710,7 @@ terminal_profile_edit (GSettings  *profile,
   GtkBuilder *builder;
   GError *error = NULL;
   GtkWidget *editor, *w;
+  char *uuid;
   guint i;
 
   editor = g_object_get_data (G_OBJECT (profile), "editor-window");
@@ -744,6 +749,11 @@ terminal_profile_edit (GSettings  *profile,
   gtk_widget_add_events (w, GDK_BUTTON_PRESS_MASK | GDK_SCROLL_MASK);
   g_signal_connect (w, "scroll-event", G_CALLBACK (scroll_event_cb), NULL);
 
+  uuid = terminal_profile_util_get_profile_uuid (profile);
+  gtk_label_set_text (GTK_LABEL (gtk_builder_get_object (builder, "profile-uuid")),
+                      uuid);
+  g_free (uuid);
+
   w = (GtkWidget *) gtk_builder_get_object  (builder, "color-scheme-combobox");
   init_color_scheme_menu (w);
 
@@ -846,6 +856,13 @@ terminal_profile_edit (GSettings  *profile,
                    gtk_builder_get_object (builder,
                                            "bold-color-same-as-fg-checkbox"),
                    "active", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  g_settings_bind (profile, TERMINAL_PROFILE_BOLD_COLOR_SAME_AS_FG_KEY,
+                   gtk_builder_get_object (builder,
+                                           "bold-colorpicker-box"),
+                   "sensitive", 
+                   G_SETTINGS_BIND_GET |
+                   G_SETTINGS_BIND_INVERT_BOOLEAN |
+                   G_SETTINGS_BIND_NO_SENSITIVITY);
   g_settings_bind_with_mapping (profile, TERMINAL_PROFILE_BOLD_COLOR_KEY,
                                 gtk_builder_get_object (builder,
                                                         "bold-colorpicker"),
@@ -922,6 +939,13 @@ terminal_profile_edit (GSettings  *profile,
                    gtk_builder_get_object (builder,
                                            "scrollback-unlimited-checkbutton"),
                    "active", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
+  g_settings_bind (profile, TERMINAL_PROFILE_SCROLLBACK_UNLIMITED_KEY,
+                   gtk_builder_get_object (builder,
+                                           "scrollback-box"),
+                   "sensitive", 
+                   G_SETTINGS_BIND_GET |
+                   G_SETTINGS_BIND_INVERT_BOOLEAN |
+                   G_SETTINGS_BIND_NO_SENSITIVITY);
   g_settings_bind_with_mapping (profile,
                                 TERMINAL_PROFILE_SCROLLBAR_POLICY_KEY,
                                 gtk_builder_get_object (builder,
@@ -997,24 +1021,6 @@ terminal_profile_edit (GSettings  *profile,
                             "sensitive",
                             FALSE);
 
-#if 0
-  if (!prop_name ||
-    prop_name == I_(TERMINAL_PROFILE_BOLD_COLOR_KEY) ||
-    prop_name == I_(TERMINAL_PROFILE_BOLD_COLOR_SAME_AS_FG_KEY) ||
-    prop_name == I_(TERMINAL_PROFILE_USE_THEME_COLORS_KEY))
-  {
-    gboolean bold_locked, bold_same_as_fg_locked, bold_same_as_fg, use_theme_colors;
-    
-    bold_locked = terminal_profile_property_locked (profile, TERMINAL_PROFILE_BOLD_COLOR_KEY);
-    bold_same_as_fg_locked = terminal_profile_property_locked (profile, TERMINAL_PROFILE_BOLD_COLOR_SAME_AS_FG_KEY);
-    bold_same_as_fg = terminal_profile_get_property_boolean (profile, TERMINAL_PROFILE_BOLD_COLOR_SAME_AS_FG_KEY);
-    
-    SET_SENSITIVE ("bold-color-same-as-fg-checkbox", !bold_same_as_fg_locked);
-    SET_SENSITIVE ("bold-colorpicker", !bold_locked && !bold_same_as_fg);
-    SET_SENSITIVE ("bold-colorpicker-label", ((!bold_same_as_fg && !bold_locked) || !bold_same_as_fg_locked));
-  }
-#endif
-
   terminal_util_bind_mnemonic_label_sensitivity (editor);
 
   terminal_profile_editor_focus_widget (editor, widget_name);
