@@ -32,6 +32,7 @@
 #include "terminal-screen.h"
 #include "terminal-screen-container.h"
 #include "terminal-window.h"
+#include "terminal-profile-utils.h"
 #include "terminal-util.h"
 #include "profile-editor.h"
 #include "terminal-encoding.h"
@@ -113,6 +114,7 @@ enum
 static void
 maybe_migrate_settings (TerminalApp *app)
 {
+#ifdef ENABLE_MIGRATION
   const char * const argv[] = { 
     TERM_LIBEXECDIR "/gnome-terminal-migration",
 #ifdef GNOME_ENABLE_DEBUG
@@ -126,7 +128,7 @@ maybe_migrate_settings (TerminalApp *app)
 
   version = g_settings_get_uint (terminal_app_get_global_settings (app), TERMINAL_SETTING_SCHEMA_VERSION);
   if (version >= TERMINAL_SCHEMA_VERSION) {
-     _terminal_debug_print (TERMINAL_DEBUG_FACTORY | TERMINAL_DEBUG_PROFILE,
+     _terminal_debug_print (TERMINAL_DEBUG_SERVER | TERMINAL_DEBUG_PROFILE,
                             "Schema version is %d, already migrated.\n", version);
     return;
   }
@@ -150,6 +152,11 @@ maybe_migrate_settings (TerminalApp *app)
   } else {
     g_printerr ("Profile migrator exited abnormally.\n");
   }
+#else
+  g_settings_set_uint (terminal_app_get_global_settings (app),
+                       TERMINAL_SETTING_SCHEMA_VERSION,
+                       TERMINAL_SCHEMA_VERSION);
+#endif /* ENABLE_MIGRATION */
 }
 
 static char **
@@ -187,21 +194,6 @@ strv_remove (char **strv,
   return strv;
 }
 
-static char *
-profile_get_uuid (GSettings *profile)
-{
-  char *path, *uuid;
-
-  g_object_get (profile, "path", &path, NULL);
-  g_assert (g_str_has_prefix (path, TERMINAL_PROFILES_PATH_PREFIX ":"));
-  uuid = g_strdup (path + strlen (TERMINAL_PROFILES_PATH_PREFIX ":"));
-  g_free (path);
-
-  g_assert (strlen (uuid) == 37);
-  uuid[36] = '\0';
-  return uuid;
-}
-
 static int
 profiles_alphabetic_cmp (gconstpointer pa,
                          gconstpointer pb)
@@ -372,7 +364,7 @@ profile_remove (TerminalApp *app,
   char **profiles;
   DConfClient *client;
 
-  uuid = profile_get_uuid (profile);
+  uuid = terminal_profile_util_get_profile_uuid (profile);
   g_object_get (profile, "path", &path, NULL);
 
   g_settings_get (app->global_settings, TERMINAL_SETTING_PROFILES_KEY, "^a&s", &profiles);
@@ -408,7 +400,7 @@ terminal_app_profile_cell_data_func (GtkTreeViewColumn *tree_column,
 
   gtk_tree_model_get (tree_model, iter, (int) COL_PROFILE, &profile, (int) -1);
   g_settings_get (profile, TERMINAL_PROFILE_VISIBLE_NAME_KEY, "&s", &text);
-  uuid = profile_get_uuid (profile);
+  uuid = terminal_profile_util_get_profile_uuid (profile);
 
   g_value_init (&value, G_TYPE_STRING);
   g_value_take_string (&value,
@@ -581,7 +573,7 @@ profile_combo_box_changed_cb (GtkWidget *widget,
   if (!profile)
     return;
 
-  uuid = profile_get_uuid (profile);
+  uuid = terminal_profile_util_get_profile_uuid (profile);
   g_settings_set_string (app->global_settings, TERMINAL_SETTING_DEFAULT_PROFILE_KEY, uuid);
 
   g_free (uuid);
@@ -811,46 +803,6 @@ profile_list_row_activated_cb (GtkTreeView       *tree_view,
   g_object_unref (selected_profile);
 }
 
-static gboolean
-validate_profile_name (const char *name)
-{
-  uuid_t u;
-
-  return uuid_parse ((char *) name, u) == 0;
-}
-
-static gboolean
-validate_profile_list (char **profiles)
-{
-  guint i;
-
-  g_assert (profiles != NULL);
-
-  for (i = 0; profiles[i]; i++) {
-    if (!validate_profile_name (profiles[i]))
-      return FALSE;
-  }
-
-  return i > 0;
-}
-
-static gboolean
-map_profiles_list (GVariant *value,
-                   gpointer *result,
-                   gpointer user_data G_GNUC_UNUSED)
-{
-  char **profiles;
-
-  g_variant_get (value, "^a&s", &profiles);
-  if (validate_profile_list (profiles)) {
-    *result = profiles;
-    return TRUE;
-  }
-
-  g_free (profiles);
-  return FALSE;
-}
-
 static void
 terminal_app_profile_list_changed_cb (GSettings *settings,
                                       const char *key,
@@ -864,8 +816,7 @@ terminal_app_profile_list_changed_cb (GSettings *settings,
   /* Use get_mapped so we can be sure never to get valid profile names, and
    * never an empty profile list, since the schema defines one profile.
    */
-  profiles = g_settings_get_mapped (app->global_settings, TERMINAL_SETTING_PROFILES_KEY,
-                                    map_profiles_list, NULL);
+  profiles = terminal_profile_util_get_profiles (app->global_settings);
   g_settings_get (app->global_settings, TERMINAL_SETTING_DEFAULT_PROFILE_KEY,
                   "&s", &default_profile);
 
@@ -895,7 +846,7 @@ terminal_app_profile_list_changed_cb (GSettings *settings,
 
     g_hash_table_insert (new_profiles, g_strdup (name) /* adopted */, profile /* adopted */);
   }
-  g_free (profiles);
+  g_strfreev (profiles);
 
   g_assert (g_hash_table_size (new_profiles) > 0);
 
@@ -1173,18 +1124,12 @@ terminal_app_startup (GApplication *application)
 
   GtkBuilder *builder;
   GError *error = NULL;
-  gboolean shell_shows_app_menu;
 
   G_APPLICATION_CLASS (terminal_app_parent_class)->startup (application);
 
   /* Need to set the WM class (bug #685742) */
   gdk_set_program_class("Gnome-terminal");
 
-  /* Only install the app menu if it's going to be shown */
-  g_object_get (gtk_settings_get_for_screen (gdk_screen_get_default ()), "gtk-shell-shows-app-menu", &shell_shows_app_menu, NULL);
-  if (!shell_shows_app_menu)
-    return;
-
   g_action_map_add_action_entries (G_ACTION_MAP (application),
                                    app_menu_actions, G_N_ELEMENTS (app_menu_actions),
                                    application);
@@ -1198,6 +1143,8 @@ terminal_app_startup (GApplication *application)
   gtk_application_set_app_menu (GTK_APPLICATION (application),
                                 G_MENU_MODEL (gtk_builder_get_object (builder, "appmenu")));
   g_object_unref (builder);
+
+  _terminal_debug_print (TERMINAL_DEBUG_SERVER, "Startup complete\n");
 }
 
 /* GObjectClass impl */
@@ -1451,7 +1398,7 @@ terminal_app_ref_profile_by_uuid (TerminalApp *app,
   GSettings *profile = NULL;
 
   if (uuid == NULL)
-    uuid = g_settings_get_string (app->global_settings, TERMINAL_SETTING_DEFAULT_PROFILE_KEY);
+    g_settings_get (app->global_settings, TERMINAL_SETTING_DEFAULT_PROFILE_KEY, "&s", &uuid);
 
   profile = g_hash_table_lookup (app->profiles_hash, uuid);
 
