@@ -27,7 +27,7 @@ G_BEGIN_DECLS
 typedef enum {
   TERMINAL_DEBUG_ACCELS     = 1 << 0,
   TERMINAL_DEBUG_ENCODINGS  = 1 << 1,
-  TERMINAL_DEBUG_FACTORY    = 1 << 2,
+  TERMINAL_DEBUG_SERVER    = 1 << 2,
   TERMINAL_DEBUG_GEOMETRY   = 1 << 3,
   TERMINAL_DEBUG_MDI        = 1 << 4,
   TERMINAL_DEBUG_PROCESSES  = 1 << 5,
