@@ -2,12 +2,12 @@
  * Copyright © 2002 Red Hat, Inc.
  * Copyright © 2008 Christian Persch
  *
- * Gnome-terminal is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Gnome-terminal is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -459,17 +459,13 @@ terminal_encoding_dialog_show (GtkWindow *transient_parent)
 
   data = g_new (EncodingDialogData, 1);
 
-  if (!terminal_util_load_builder_resource ("/org/gnome/terminal/ui/encodings-dialog.ui",
-                                            "encodings-dialog", &data->dialog,
-                                            "add-button", &data->add_button,
-                                            "remove-button", &data->remove_button,
-                                            "available-treeview", &data->available_tree_view,
-                                            "displayed-treeview", &data->active_tree_view,
-                                            NULL))
-    {
-      g_free (data);
-      return;
-    }
+  terminal_util_load_builder_resource ("/org/gnome/terminal/ui/encodings-dialog.ui",
+                                       "encodings-dialog", &data->dialog,
+                                       "add-button", &data->add_button,
+                                       "remove-button", &data->remove_button,
+                                       "available-treeview", &data->available_tree_view,
+                                       "displayed-treeview", &data->active_tree_view,
+                                       NULL);
 
   g_object_set_data_full (G_OBJECT (data->dialog), "GT::Data", data, (GDestroyNotify) encoding_dialog_data_free);
 
