@@ -2,9 +2,9 @@
  * Copyright © 2005 Paolo Maggi
  * Copyright © 2010 Red Hat (Red Hat author: Behdad Esfahbod)
  *
- * This program is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,9 +13,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330,
- * Boston, MA 02111-1307, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -83,20 +81,16 @@ terminal_search_dialog_new (GtkWindow   *parent)
 
   priv = g_new0 (TerminalSearchDialogPrivate, 1);
 
-  if (!terminal_util_load_builder_resource ("/org/gnome/terminal/ui/find-dialog.ui",
-                                            "find-dialog", &dialog,
-                                            "search-label", &priv->search_label,
-                                            "search-entry", &priv->search_entry,
-                                            "match-case-checkbutton", &priv->match_case_checkbutton,
-                                            "entire-word-checkbutton", &priv->entire_word_checkbutton,
-                                            "regex-checkbutton", &priv->regex_checkbutton,
-                                            "search-backwards-checkbutton", &priv->backwards_checkbutton,
-                                            "wrap-around-checkbutton", &priv->wrap_around_checkbutton,
-                                            NULL))
-  {
-    g_free (priv);
-    return NULL;
-  }
+  terminal_util_load_builder_resource ("/org/gnome/terminal/ui/find-dialog.ui",
+                                       "find-dialog", &dialog,
+                                       "search-label", &priv->search_label,
+                                       "search-entry", &priv->search_entry,
+                                       "match-case-checkbutton", &priv->match_case_checkbutton,
+                                       "entire-word-checkbutton", &priv->entire_word_checkbutton,
+                                       "regex-checkbutton", &priv->regex_checkbutton,
+                                       "search-backwards-checkbutton", &priv->backwards_checkbutton,
+                                       "wrap-around-checkbutton", &priv->wrap_around_checkbutton,
+                                       NULL);
 
   g_object_set_qdata_full (G_OBJECT (dialog), get_quark (), priv,
 			   (GDestroyNotify) terminal_search_dialog_private_destroy);
